@@ -17,6 +17,8 @@ import Control.Monad (forever)
 import Data.ByteString.Lazy qualified as BL
 import Effectful
 import Effectful.Concurrent.Async
+import Effectful.Concurrent.STM (TVar)
+import GHC.Conc (newTVarIO)
 import Network.Wai qualified as Wai
 import Network.Wai.Handler.WebSockets (websocketsOr)
 import Network.WebSockets (ConnectionException (..), PendingConnection, defaultConnectionOptions, withPingThread)
@@ -27,14 +29,14 @@ import Web.Hyperbole.Effect.Request (reqPath)
 import Web.Hyperbole.Effect.Response (notFound)
 import Web.Hyperbole.Route
 import Web.Hyperbole.Server.Options
-import Web.Hyperbole.Server.Socket (handleRequestSocket)
+import Web.Hyperbole.Server.Socket (RunningActions, handleRequestSocket)
 import Web.Hyperbole.Server.Wai (handleRequestWai)
 import Web.Hyperbole.Types.Response
 
 
 {- | Turn one or more 'Page's into a Wai Application. Respond using both HTTP and WebSockets
 
-> #EMBED Example/Docs/BasicPage.hs main
+> #EMBED Example.Docs.BasicPage main
 -}
 liveApp :: (BL.ByteString -> BL.ByteString) -> Eff '[Hyperbole, Concurrent, IOE] Response -> Wai.Application
 liveApp doc =
@@ -47,26 +49,27 @@ liveApp doc =
 
 -- | Run a Hyperbole application, customizing both the document and the format of server errors
 liveAppWith :: ServerOptions -> Eff '[Hyperbole, Concurrent, IOE] Response -> Wai.Application
-liveAppWith opts app req =
+liveAppWith opts eff req = do
   websocketsOr
     defaultConnectionOptions
-    (\pend -> socketApp opts req app pend `catch` suppressMessages)
-    (waiApp opts app)
+    (\pend -> socketApp opts req eff pend `catch` suppressMessages)
+    (waiApp opts eff)
     req
 
 
 waiApp :: ServerOptions -> Eff '[Hyperbole, Concurrent, IOE] Response -> Wai.Application
-waiApp opts actions req res = do
-  runEff $ runConcurrent $ handleRequestWai opts req res actions
+waiApp opts eff req res = do
+  runEff $ runConcurrent $ handleRequestWai opts req res eff
 
 
-socketApp :: ServerOptions -> Wai.Request -> Eff '[Hyperbole, Concurrent, IOE] Response -> PendingConnection -> IO ()
-socketApp opts req actions pend = do
-  conn <- liftIO $ WS.acceptRequest pend
-  -- ping to keep the socket alive
+socketApp :: (MonadIO m) => ServerOptions -> Wai.Request -> Eff '[Hyperbole, Concurrent, IOE] Response -> PendingConnection -> m ()
+socketApp opts req eff pend = liftIO $ do
+  -- private TVar for each client
+  actions :: TVar RunningActions <- liftIO $ newTVarIO mempty
+  conn <- WS.acceptRequest pend
   withPingThread conn 25 (pure ()) $ do
     forever $ do
-      runEff $ runConcurrent $ handleRequestSocket opts req conn actions
+      runEff $ runConcurrent $ handleRequestSocket opts actions req conn eff
 
 
 suppressMessages :: ConnectionException -> IO a
@@ -87,15 +90,15 @@ suppressMessages ex = do
 
 
 @
-#EMBED Example/Docs/App.hs import Example.Docs.Page
+#EMBED Example.Docs.App type UserId
 
-#EMBED Example/Docs/App.hs type UserId
+#EMBED Example.Docs.App data AppRoute
 
-#EMBED Example/Docs/App.hs data AppRoute
+#EMBED Example.Docs.App instance Route
 
-#EMBED Example/Docs/App.hs instance Route
+#EMBED Example.Docs.App router
 
-#EMBED Example/Docs/App.hs router
+#EMBED Example.Docs.App app
 @
 -}
 routeRequest :: (Hyperbole :> es, Route route) => (route -> Eff es Response) -> Eff es Response
