@@ -9,31 +9,33 @@ import Web.Hyperbole.Effect.Hyperbole
 import Web.Hyperbole.HyperView
 import Web.Hyperbole.Types.Client (clientSetPageTitle)
 import Web.Hyperbole.Types.Event
+import Web.Hyperbole.View (toAction, toViewId)
 
 
 {- | Trigger an action for an arbitrary 'HyperView'
 
-#EXAMPLE /advanced
-
 @
-#EMBED Example/Page/Advanced.hs instance HyperView Controls
+#EMBED Example.Trigger instance HyperView Controls
 @
 -}
 trigger :: (HyperView id es, HyperViewHandled id view, Hyperbole :> es) => id -> Action id -> Eff (Reader view : es) ()
 trigger vid act = do
-  send $ TriggerAction (TargetViewId $ encodeViewId vid) (toAction act)
+  send $ TriggerAction (TargetViewId $ toViewId vid) (toAction act)
 
 
 {- | Dispatch a custom javascript event. This is emitted on the current hyper view and bubbles up to the document
 
-#EXAMPLE /javascript
-
 @
-#EMBED Example/Page/Javascript.hs instance HyperView Message
+#EMBED Example.Javascript instance HyperView Message
 @
 
 @
-#EMBED static/custom.js function listenServerEvents
+function listenServerEvents() {
+  // you can listen on document instead, the event will bubble
+  Hyperbole.hyperView("Message").addEventListener("server-message", function(e) {
+    alert("Server Message: " + e.detail)
+  })
+}
 @
 -}
 pushEvent :: (ToJSON a, Hyperbole :> es) => Text -> a -> Eff es ()
@@ -44,7 +46,7 @@ pushEvent nm a = do
 {- | Set the document title
 
 @
-#EMBED Example/Docs/Client.hs page
+#EMBED Example.Docs.Client page
 @
 -}
 pageTitle :: (Hyperbole :> es) => Text -> Eff es ()
