@@ -1,4 +1,3 @@
-{-# LANGUAGE LambdaCase #-}
 {-# LANGUAGE UndecidableInstances #-}
 
 module Web.Hyperbole.Effect.Hyperbole where
@@ -6,7 +5,6 @@ module Web.Hyperbole.Effect.Hyperbole where
 import Data.Aeson (Value)
 import Data.Text (Text)
 import Effectful
-import Effectful.Dispatch.Dynamic
 import Effectful.Error.Static
 import Effectful.State.Static.Local
 import Effectful.Writer.Static.Local
@@ -21,6 +19,7 @@ import Web.Hyperbole.Types.Response
 data Hyperbole :: Effect where
   GetRequest :: Hyperbole m Request
   RespondNow :: Response -> Hyperbole m a
+  PushUpdate :: ViewUpdate -> Hyperbole m ()
   ModClient :: (Client -> Client) -> Hyperbole m ()
   GetClient :: Hyperbole m Client
   -- TODO: this should actually execute the other view, and send the response to the client
@@ -36,30 +35,11 @@ data Remote
   | RemoteEvent Text Value
 
 
--- | Run the 'Hyperbole' effect to get a response
-runHyperbole
-  :: Request
-  -> Eff (Hyperbole : es) Response
-  -> Eff es (Response, Client, [Remote])
-runHyperbole req = reinterpret runLocal $ \_ -> \case
-  GetRequest -> do
-    pure req
-  RespondNow r -> do
-    throwError_ r
-  GetClient -> do
-    get @Client
-  ModClient f -> do
-    modify @Client f
-  TriggerAction vid act -> do
-    tell [RemoteAction vid act]
-  TriggerEvent name dat -> do
-    tell [RemoteEvent name dat]
+runHyperboleLocal :: Request -> Eff (Error Response : State Client : Writer [Remote] : es) Response -> Eff es (Response, Client, [Remote])
+runHyperboleLocal req eff = do
+  ((eresp, client'), rmts) <- runWriter @[Remote] . runState (emptyClient req.requestId) . runErrorNoCallStack @Response $ eff
+  pure (either id id eresp, client', rmts)
  where
-  runLocal :: Eff (Error Response : State Client : Writer [Remote] : es) Response -> Eff es (Response, Client, [Remote])
-  runLocal eff = do
-    ((eresp, client'), rmts) <- runWriter @[Remote] . runState (emptyClient req.requestId) . runErrorNoCallStack @Response $ eff
-    pure (either id id eresp, client', rmts)
-
   emptyClient :: RequestId -> Client
   emptyClient requestId =
     Client
