@@ -2,15 +2,20 @@ module Web.Hyperbole.HyperView
   ( module Web.Hyperbole.HyperView.Types
   , module Web.Hyperbole.HyperView.Input
   , module Web.Hyperbole.HyperView.Event
-  , module Web.Hyperbole.HyperView.ViewId
-  , module Web.Hyperbole.HyperView.ViewAction
   , module Web.Hyperbole.HyperView.Handled
+  , module Web.Hyperbole.HyperView.Hyper
+  , get
+  , put
+  , gets
+  , modify
+  , state
+  , State
   ) where
 
+import Effectful.State.Dynamic
 import Web.Hyperbole.HyperView.Event
 import Web.Hyperbole.HyperView.Handled
+import Web.Hyperbole.HyperView.Hyper
 import Web.Hyperbole.HyperView.Input
 import Web.Hyperbole.HyperView.Types
-import Web.Hyperbole.HyperView.ViewAction
-import Web.Hyperbole.HyperView.ViewId
 
