@@ -1,5 +1,7 @@
 module Web.Hyperbole.View
   ( module Web.Hyperbole.View.Types
+  , module Web.Hyperbole.View.ViewId
+  , module Web.Hyperbole.View.ViewAction
   , module Web.Hyperbole.View.Embed
   , module Web.Hyperbole.View.Render
   , module Web.Hyperbole.View.Tag
@@ -12,5 +14,7 @@ import Web.Hyperbole.View.CSS
 import Web.Hyperbole.View.Embed
 import Web.Hyperbole.View.Render
 import Web.Hyperbole.View.Tag hiding (form, input, label)
-import Web.Hyperbole.View.Types (View (..), addContext, context, modifyContext, none, raw, tag, text)
+import Web.Hyperbole.View.Types
+import Web.Hyperbole.View.ViewAction
+import Web.Hyperbole.View.ViewId
 
